SystemOrganization addCategory: #ConfigurationOfGameCore!

Object subclass: #ConfigurationOfGameCore
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfGameCore'!

!ConfigurationOfGameCore commentStamp: 'RafaelLuque 11/13/2014 13:51' prior: 0!
A ConfigurationOfGameCore is a Metacello configuration for GameCore project.!

!ConfigurationOfGameCore class methodsFor: 'development support' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfGameCore class methodsFor: 'private' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfGameCore class methodsFor: 'private' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfGameCore class methodsFor: 'private' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfGameCore class methodsFor: 'metacello tool support' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfGameCore class methodsFor: 'loading' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfGameCore class methodsFor: 'loading' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfGameCore class methodsFor: 'loading' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfGameCore class methodsFor: 'accessing' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
project

	^self new project! !

!ConfigurationOfGameCore class methodsFor: 'development support' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfGameCore methodsFor: 'baselines' stamp: 'JoseSanLeandro 7/9/2015 20:24'!
baseline01: spec
	<version: '0.1-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'gitfiletree://' , FileSystem workingDirectory fullName.
			spec
				project: 'Marea' with: [
				spec
					className: #'ConfigurationOfMarea';
					versionString: '1.2-baseline';
					repository: 'http://www.squeaksource.com/Marea';
					loads: #('GhostProxies') ].
			spec
				project: 'Logging' with: [
				spec
					className: #'G9Logger';
					repository: 'http://ss3.gemtalksystems.com/ss/SimpleLogger';
					loads: #('G9Logger') ].
			spec
				project: 'Pharo-EDA-Common'
				with: [ 
					spec
						className: 'ConfigurationOfPharoEDA';
						repository: 'gitfiletree://' , FileSystem workingDirectory parent fullName, '/pharo-eda-common';
						versionString: #'bleedingEdge' ];
				project: 'Game-Image-Processor-Commands'
				with: [ 
					spec
						className: 'ConfigurationOfGameImageProcessor';
						repository: 'gitfiletree://' , FileSystem workingDirectory parent fullName, '/game-image-processor';
						versionString: #'bleedingEdge';
						loads: #('commands') ].
			spec
				package: 'GameCore-Domain';
				package: 'GameCore-Domain-Tests'
					with: [ spec requires: #('GameCore-Domain' 'Pharo-EDA-Common') ];
				package: 'GameCore-Application'
					with: [ spec requires: #('GameCore-Domain' 'Pharo-EDA-Common') ];
				package: 'GameCore-Application-Tests' with: [  spec requires: #('GameCore-Application') ];
				package: 'GameCore-Settings';
				package:	'GameCore-Images';
				package: 'GameCore-Images-RemoteService' with: [ spec requires: #('Game-Image-Processor-Commands') ].
			spec
				group: 'core' with: #(#'GameCore-Domain' #'GameCore-Application' #'GameCore-Settings' #'GameCore-Images' #'GameCore-Images-RemoteService');
				group: 'tests' with: #(#'GameCore-Domain-Tests' #'GameCore-Application-Tests' );
				group: 'default' with: #('core' 'tests' ). 	]! !

!ConfigurationOfGameCore methodsFor: 'accessing' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfGameCore methodsFor: 'symbolic versions' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
development: spec
	<symbolicVersion: #development>
	spec for: #'common' version: '0.1'.! !

!ConfigurationOfGameCore methodsFor: 'accessing' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
project

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfGameCore methodsFor: 'versions' stamp: 'RafaelLuque 5/4/2015 11:01:45'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #development;
				package: 'GameCore-Domain' with: 'GameCore-Domain-RafaelLuque.1';
				package: 'GameCore-Application' with: 'GameCore-Application-RafaelLuque.1';
				package: 'GameCore-Messaging' with: 'GameCore-Messaging-RafaelLuque.1';
				package: 'GameCore-EventStore' with: 'GameCore-EventStore-RafaelLuque.1';
				package: 'GameCore-StompMessaging' with: 'GameCore-StompMessaging-RafaelLuque.1';
				package: 'GameCore-ImageEventStore' with: 'GameCore-ImageEventStore-RafaelLuque.1';
				package: 'GameCore-Domain-Tests' with: 'GameCore-Domain-Tests-RafaelLuque.1';
				project: 'Stamp' with: '1' ]! !
